@@ -1,4 +1,4 @@
-# $Id: Plugin.pm 743 2005-08-20 22:50:22Z claco $
+# $Id: Plugin.pm 1335 2006-07-15 02:43:12Z claco $
 package Handel::Checkout::Plugin;
 use strict;
 use warnings;
@@ -46,25 +46,25 @@ Handel::Checkout::Plugin - Base module for Handle::Checkout plugins
     package MyPackage::FaxOrder;
     use Handel::Constants qw(:checkout);
     use base 'Handel::Checkout::Plugin';
-
+    
     sub register {
         my ($self, $ctx) = @_;
 
         $ctx->add_handler(CHECKOUT_PHASE_DELIVER, \&deliver);
     };
-
+    
     sub deliver {
         my ($self, $ctx) = @_;
-
+    
         ...
-
+    
         return CHECKOUT_HANDLER_OK;
     };
 
 =head1 DESCRIPTION
 
-C<Handel::Checkout::Plugin> is the base module for all checkout pipeline
-plugins used in C<Handel::Checkout>.
+Handel::Checkout::Plugin is the base module for all checkout pipeline plugins
+used in Handel::Checkout.
 
 =head1 CONSTRUCTOR
 
@@ -108,13 +108,13 @@ A plugin can register any number of methods with any number of phases.
 
 Each time a checkout pipeline is processed, the C<setup> method is called
 on all registered plugins to allow each plugin to perform any
-necessary preperation before its registered handler subs are called.
+necessary preparation before its registered handler subs are called.
 
 =head2 teardown
 
 Each time a checkout pipeline is finished being processed, the
 C<teardown> method is called on all registered plugins to allow each plugin
-to performa any cleanup it may need to do.
+to perform any cleanup it may need to do.
 
 =head2 name
 
