@@ -1,9 +1,9 @@
-# $Id: ValidateError.pm 1168 2006-05-31 01:53:05Z claco $
+# $Id: ValidateError.pm 1336 2006-07-15 03:54:43Z claco $
 package Handel::TestPipeline::ValidateError;
 use strict;
 use warnings;
 use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout :returnas);
+use Handel::Constants qw(:checkout);
 
 sub register {
     my ($self, $ctx) = @_;
